#!/bin/bash 
# eseguibackup.sh
# vers. 1.0.2

#
# ### MEM - Backup quotidiano [0.4]:
#
# ==============================================
#
# Questo script puo' essere lanciato tramite cron
# per eseguire il salvataggio su natro DAT del filesystem
# indicato nelle variabili : 
#
[ $(id -u) != "0" ] && echo "# ### Devi essere root.." && exit -1

# NMB:
# Se viene passato un secondo parametro, questo sara' la lista delle 
# cartelle che vanno inserite nel salvataggio. Utile per consentire
# allo script maggiore flessibilita'..
#
[ "$#" -gt "1" ] && echo "# Utilizzo: $0 \"[lista cartelle]\"" && exit -1

###############################################################################
# ### VARIABILI DI SISTEMA:
###############################################################################
#
# - cosaCopiare:
#       La lista delle cartelle e dei files che devono essere inseriti nel salvataggio. 
#       Questo parametro puo' essere indicato da riga di comando.
#       (per una migliore lettura e' possibile inserire su piu' righe )
#

if [ -n "$1" ]; then
    # Se viene passato un parametro a questo script, si presuppone che non vengano
    # indicati percorsi non esistenti. :o)
    cosaCopiare="$1"
else
    # Qualora non fosse passato nessun parametro allo script,
    # si procede nel salvataggio di queste cartelle :
    
    # Def: Cartelle di default
    # 28 maggio 06 **  eliminato per problemi di spazio su dat la copia 
    # della home e delle mappe
    cosaCopiare="/etc /home"    
fi

##############################################################################
# ### VARIABILI DI AMBIENTE:
##############################################################################
#
#
# - supportoCopie:
#       Il supporto sul quale salvare il backup compresso.
#       Puo' semplicemente essere il dispositivo (/dev/st0) ovvero indicare
#       il nome del file che verra' salvato (/tmp/miobackup.tar.gz)
#
#
# Def: Utilizzo il nastro DAT.
supportoCopie="/dev/st0"


#
# - doveLavoro:
#       Questa e' la cartella di lavoro. In essa andranno riposti i files di log,
#       ma anche il risultato del salvataggio eseguito.. 
# Def:
doveLavoro="/home/samba/condivisa/Varie"


#
# - compressione:
#       Indicando il livello di compressione e' possibile ottenere un salvataggio
#       piu' performante. Le opzioni possono essere le seguenti:
#
#           "0" - Nessuna compressione
#           "1" - Compressione gzip (.tar.gz)
#           "2" - Compressione bzip (.tar.bz2)
#
# Def: Compressione massima 
compressione="1"

#
# - listaFiles :
#       Lista di tutte le cartelle e di tutti i files salvati. 
#       Questo file viene compilato dal processo di backup.
#
# Def: /tmp/backup-listafiles.log
listaFiles="$doveLavoro/backup-listafiles.log"

#
# - risultatoCopie:
#       Il file nel quale inserire il risultato delle copie 
#       su nastro. Questo file deve appartenere al cliente finale
#       o meglio all'utente che fa il controllo sulle copie nastro.
#
#       NMB: Questo file viene attualmente sovrascritto.
#
#               Per avere un maggiore controllo sul servizio di backup
#               quotidiano si potrebbe creare un file in funzione del giorno
#               nel quale il backup viene eseguito (storico)
#
#
# Def:/tmp/backup-risultato.log
risultatoCopie="$doveLavoro/backup-risultato.log"

# ### Esecuzione salvataggio su natro DAT:
# Il salvataggio viene effettuato in formato compresso .tar.bz2
# in modo da risparmiare spazio su disco. Il backup potrebbe essere
# studiato al megli per essere INCREMENTALE e non TOTALE.
#
# Questo potrebbe non solo velocizzare il salvataggio,
# ma anche eliminare eventuali conflitti di files..
#

case "$compressione" in 
    
    "0") 
        /bin/tar cvf $supportoCopie $cosaCopiare	> $listaFiles 
    ;;
    "1")
        /bin/tar cvzf $supportoCopie $cosaCopiare	> $listaFiles 
    ;;
    "2")
        /bin/tar cvjf $supportoCopie $cosaCopiare	> $listaFiles 
    ;;
    
esac

# ### Verifica del risultato :
# Dopo aver verificato che le copie siano andate a buon fine,
# prevedo l'espulsione del nastro DAT ed eventualmente 
# lo spegnimento del sistema. 
#
if [ "$?" == "0" ]; then 
    echo "# =========================================="          > $risultatoCopie
    echo "# [$(date +%d-%m-%Y)] Backup terminato con successo. " >> $risultatoCopie
    echo "# =========================================="          >> $risultatoCopie
    echo "# Queste le cartelle che sono state salvate :"         >> $risultatoCopie
    echo "#"
    echo "#"
   	echo $cosaCopiare    >> $risultatoCopie
    echo "#"
    echo "#"
    echo "# =========================================="          >> $risultatoCopie
 
    # Avendo completato con successo il salvataggio:
    #
    # * Espulsione nastro DAT
    [ "$supportoCopie" == "/dev/st0" ] && /bin/mt -f /dev/st0 eject && sleep 15
    
    # * Spegnimento del sistema
    /sbin/shutdown -h now
    exit 0
    
else
    echo "# ======================================== #"  >  $listaFiles
    echo "#       NESSUN FILE E' STATO COPIATO!!     #"  >> $listaFiles
    echo "# ======================================== #"  >> $listaFiles

    echo "# ========================================================================= #"          > $risultatoCopie
    echo "# [$(date +%d-%m-%Y)] ATTENZIONE!! Il Backup non e' terminato correttamente " >> $risultatoCopie
    echo "# ========================================================================= #"          >> $risultatoCopie

    # * Spegnimento del sistema
    /sbin/shutdown -h now
    exit 0
fi

